..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


======================================
 Invenio v3 Digital Library Framework
======================================

.. image:: https://img.shields.io/travis/inveniosoftware/invenio.svg
        :target: https://travis-ci.org/inveniosoftware/invenio

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/inveniosoftware/invenio?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

Invenio is a digital library framework that enables you to build and run your
own large scale digital repository.

Invenio can be used either as an underlying framework or via the currently one
pre-packaged flavour which is ready to run out-of-the-box:

- Invenio v3 Integrated Library System (ILS)

Three further pre-packaged flavours are planned:

- Invenio v3 Research Data Management (RDM)
- Invenio v3 Media Archive (MA)
- Invenio v3 Institutional Repository (IR)

Invenio is currently powering some of the largest digital repositories in the
world such as:

- `CERN Document Server <http://cds.cern.ch>`_  (v1)
- `CERN Open Data Repository <http://opendata.cern.ch>`_  (v2)
- `INSPIRE High-Energy Physics Repository <http://inspirehep.net>`_  (v1)
- `Caltech Library Catalog <http://caltech.tind.io>`_  (v1)
- `DESY Publication Database <https://pubdb.desy.de/>`_  (v1)
- `Zenodo research data repository <https://www.zenodo.org>`_ (v3)


.. warning::

    **WORK IN PROGRESS** Invenio v3.0 Release Candidate 1 was released on
    April 23, 2018. We expect a final release of Invenio v3.0 by end-May 
    2018 after the next Invenio sprint (May 14-25). The missing parts 
    include this general documentation, site templates and an update of 
    the main website. All the indivdual packages (code and documentation) 
    that make up Invenio v3.0 have already been released in stable v1.0 
    versions.
